@@ -84,7 +84,7 @@ struct Gsasl_session
   void *application_hook;
 
   /* Properties.  If you add anything here, remember to change change
-     gsasl_finish().  */
+     gsasl_finish() in xfinish.c and map() in property.c.  */
   char *anonymous_token;
   char *authid;
   char *authzid;
@@ -97,6 +97,11 @@ struct Gsasl_session
   char *gssapi_display_name;
   char *realm;
   char *digest_md5_hashed_password;
+  char *qops;
+  char *qop;
+  char *scram_iter;
+  char *scram_salt;
+  char *scram_salted_password;
 
 #ifndef GSASL_NO_OBSOLETE
   /* Obsolete stuff. */
